==> elasticsearch-6.3.1-sources.jar: org/elasticsearch/script/ScriptEngine.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.script;

import java.io.Closeable;
import java.io.IOException;
import java.util.Map;

/**
 * A script language implementation.
 */
public interface ScriptEngine extends Closeable {

    /**
     * The language name used in the script APIs to refer to this scripting backend.
     */
    String getType();

    /**
     * Compiles a script.
     * @param name the name of the script. {@code null} if it is anonymous (inline). For a stored script, its the identifier.
     * @param code actual source of the script
     * @param context the context this script will be used for
     * @param params compile-time parameters (such as flags to the compiler)
     * @return A compiled script of the FactoryType from {@link ScriptContext}
     */
    <FactoryType> FactoryType compile(String name, String code, ScriptContext<FactoryType> context, Map<String, String> params);

    @Override
    default void close() throws IOException {}
}

==> elasticsearch-7.10.2-sources.jar: org/elasticsearch/script/ScriptEngine.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.script;

import java.io.Closeable;
import java.io.IOException;
import java.util.Map;
import java.util.Set;

/**
 * A script language implementation.
 */
public interface ScriptEngine extends Closeable {

    /**
     * The language name used in the script APIs to refer to this scripting backend.
     */
    String getType();

    /**
     * Compiles a script.
     * @param name the name of the script. {@code null} if it is anonymous (inline). For a stored script, its the identifier.
     * @param code actual source of the script
     * @param context the context this script will be used for
     * @param params compile-time parameters (such as flags to the compiler)
     * @return A compiled script of the FactoryType from {@link ScriptContext}
     */
    <FactoryType> FactoryType compile(
        String name,
        String code,
        ScriptContext<FactoryType> context,
        Map<String, String> params
    );

    @Override
    default void close() throws IOException {}

    /**
     * Script contexts supported by this engine.
     */
    Set<ScriptContext<?>> getSupportedContexts();
}
